@@ -1,6 +1,6 @@
 import numpy as np
 import pandas as pd
-from scipy.stats import (binom_test, beta, multinomial, poisson)
+from scipy.stats import (binom, binom_test, beta, multinomial, poisson, norm)
 
 class HC(object) :
     """
@@ -397,7 +397,7 @@ def binom_test_two_sided_random(x, n, p) :
     
 #     return hc_star, p_thresh
 
-def binom_var_test_df(c1, c2, sym=False, max_m=-1) :
+def binom_var_test_df(c1, c2, sym=False, max_m=-1, singleton=True) :
     """ Binmial variance test along stripes. 
         This version returns all sub-calculations
     Args:
@@ -439,10 +439,11 @@ def binom_var_test_df(c1, c2, sym=False, max_m=-1) :
     df_hist.loc[:,'pval'] = df_hist.z.apply(lambda z : norm.sf(z))
 
     # handle the case m=1 seperately
-    n1 = df_hist[(df_hist.n1 == 1) & (df_hist.n2 == 0)].N.values
-    n2 = df_hist[(df_hist.n1 == 0) & (df_hist.n2 == 1)].N.values
-    if len(n1) + len(n2) >= 2 :
-        df_hist.loc[df_hist.m == 1,'pval'] = binom_test_two_sided(n1, n1 + n2 , 1/2)
+    if singleton :
+        n1 = df_hist[(df_hist.n1 == 1) & (df_hist.n2 == 0)].N.values
+        n2 = df_hist[(df_hist.n1 == 0) & (df_hist.n2 == 1)].N.values
+        if len(n1) + len(n2) >= 2 :
+            df_hist.loc[df_hist.m == 1,'pval'] = binom_test_two_sided(n1, n1 + n2 , 1/2)
 
     return df_hist
 
